@@ -28,15 +28,15 @@ static const char* DATE_CLASS    = "Panda::Date";
 static const char* DATEREL_CLASS = "Panda::Date::Rel";
 static const char* DATEINT_CLASS = "Panda::Date::Int";
 
-inline const tz* tzget_required (SV* zone) {
+inline const tz* tzget_required (pTHX_ SV* zone) {
     return (zone && SvOK(zone)) ? tzget(SvPV_nolen(zone)) : tzlocal();
 }
 
-inline const tz* tzget_optional (SV* zone) {
+inline const tz* tzget_optional (pTHX_ SV* zone) {
     return zone ? (SvOK(zone) ? tzget(SvPV_nolen(zone)) : tzlocal()) : NULL;
 }
 
-inline void daterel_chkro (const DateRel* THIS) {
+inline void daterel_chkro (pTHX_ const DateRel* THIS) {
     if (THIS->is_const()) croak("Panda::Date::Rel: cannot change this object - it's read only");
 }
 
